@@ -27,6 +27,7 @@ class JustpyDemoApp:
             debug(bool): if True switch on debug mode
             **kwargs: further keyword arguments to pass to the webpage function
         """
+        self.debug=debug
         self.examples_dir=examples_dir
         self.pymodule_file = pymodule_file
         self.example_source=ExampleSource.of_path(pymodule_file)
@@ -51,6 +52,8 @@ class JustpyDemoApp:
         """
         self.is_demo = False
         if "Demo(" or "Demo (" in self.source:
+            if self.debug:
+                print(f"found Demo( in {self.pymodule_file}")
             func_match = re.search(
                 """Demo[ ]?[(]["'](.*)["'],\s*(.*?)(,.*)*[)]""", self.source
             )
@@ -61,6 +64,8 @@ class JustpyDemoApp:
                 module_match = re.search(
                     "justpy/(workspace/)?(examples/.*)[.]py", self.pymodule_file
                 )
+                if self.debug:
+                    print(f"found {self.wpfunc_name}:{self.description} in {self.pymodule_file}")
                 if module_match:
                     self.pymodule = module_match.group(2)
                     self.pymodule = self.pymodule.replace("/", ".")
